summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirtreeiterators.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:19 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:19 -0600
commitc71ade2e373d85acf1357494b42202293dd771d2 (patch)
tree76c8495d353757024fe915f12a1c7131403d9b5a /kdirstat/kdirtreeiterators.cpp
parentc3b1da745f458ff94caeca961a7d432fa6ae703b (diff)
downloadkdirstat-c71ade2e373d85acf1357494b42202293dd771d2.tar.gz
kdirstat-c71ade2e373d85acf1357494b42202293dd771d2.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kdirstat/kdirtreeiterators.cpp')
-rw-r--r--kdirstat/kdirtreeiterators.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kdirstat/kdirtreeiterators.cpp b/kdirstat/kdirtreeiterators.cpp
index 4508e8f..aac4a90 100644
--- a/kdirstat/kdirtreeiterators.cpp
+++ b/kdirstat/kdirtreeiterators.cpp
@@ -60,7 +60,7 @@ void KFileInfoIterator::next()
{
if ( ! _directChildrenProcessed )
{
// Process direct tqchildren
_current = _current ? _current->next() : _parent->firstChild();
@@ -98,7 +98,7 @@ void KFileInfoIterator::next()
{
if ( _policy == KDotEntryTransparent )
{
// Process dot entry tqchildren
_current = _current ?
_current->next() :
@@ -129,7 +129,7 @@ KFileInfoIterator::count()
{
int cnt = 0;
// Count direct tqchildren
KFileInfo *child = _parent->firstChild();
@@ -144,7 +144,7 @@ KFileInfoIterator::count()
switch ( _policy )
{
- case KDotEntryTransparent: // Count the dot entry's tqchildren as well.
+ case KDotEntryTransparent: // Count the dot entry's children as well.
if ( _parent->dotEntry() )
{
child = _parent->dotEntry()->firstChild();
@@ -183,7 +183,7 @@ KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * parent,
_sortOrder = sortOrder;
_ascending = ascending;
_initComplete = false;
- _tqchildrenList = 0;
+ _childrenList = 0;
_current = 0;
}
@@ -191,8 +191,8 @@ KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * parent,
void
KFileInfoSortedIterator::delayedInit()
{
- _tqchildrenList = new KFileInfoList( _sortOrder, _ascending );
- CHECK_PTR( _tqchildrenList );
+ _childrenList = new KFileInfoList( _sortOrder, _ascending );
+ CHECK_PTR( _childrenList );
if ( _sortOrder == KSortByName )
{
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
makeChildrenList();
}
- _current = _tqchildrenList->first();
+ _current = _childrenList->first();
_initComplete = true;
}
KFileInfoSortedIterator::~KFileInfoSortedIterator()
{
- if ( _tqchildrenList )
- delete _tqchildrenList;
+ if ( _childrenList )
+ delete _childrenList;
}
void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
{
// Fill tqchildren list with direct tqchildren
KFileInfo *child = _parent->firstChild();
while ( child )
{
- _tqchildrenList->append( child );
+ _childrenList->append( child );
child = child->next();
}
- _tqchildrenList->sort();
+ _childrenList->sort();
if ( _policy == KDotEntryAsSubDir && _parent->dotEntry() )
{
- // Append dot entry to the tqchildren list
+ // Append dot entry to the children list
- _tqchildrenList->append( _parent->dotEntry() );
+ _childrenList->append( _parent->dotEntry() );
}
// Append the dot entry's tqchildren to the tqchildren list
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
// Create a temporary list for the dot entry tqchildren
KFileInfoList dotEntryChildrenList( _sortOrder, _ascending );
child = _parent->dotEntry()->firstChild();
@@ -255,13 +255,13 @@ void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
dotEntryChildrenList.sort();
// Now append all of this dot entry tqchildren list to the tqchildren list
child = dotEntryChildrenList.first();
while ( child )
{
- _tqchildrenList->append( child );
+ _childrenList->append( child );
child = dotEntryChildrenList.next();
}
}
@@ -275,11 +275,11 @@ KFileInfoSortedIterator::makeChildrenList()
while ( *it )
{
- _tqchildrenList->append( *it );
+ _childrenList->append( *it );
++it;
}
- _tqchildrenList->sort();
+ _childrenList->sort();
}
@@ -298,7 +298,7 @@ void KFileInfoSortedIterator::next()
if ( ! _initComplete )
delayedInit();
- _current = _tqchildrenList->next();
+ _current = _childrenList->next();
}
@@ -334,12 +334,12 @@ KFileInfoSortedBySizeIterator::makeChildrenList()
while ( *it )
{
if ( (*it)->totalSize() >= _minSize )
- _tqchildrenList->append( *it );
+ _childrenList->append( *it );
++it;
}
- _tqchildrenList->sort();
+ _childrenList->sort();
}
@@ -60,7 +60,7 @@ void KFileInfoIterator::next()
if ( ! _directChildrenProcessed )
{
- // Process direct tqchildren
+ // Process direct children
_current = _current ? _current->next() : _parent->firstChild();
@@ -98,7 +98,7 @@ void KFileInfoIterator::next()
if ( _policy == KDotEntryTransparent )
{
- // Process dot entry tqchildren
+ // Process dot entry children
_current = _current ?
_current->next() :
@@ -129,7 +129,7 @@ KFileInfoIterator::count()
{
int cnt = 0;
- // Count direct tqchildren
+ // Count direct children
KFileInfo *child = _parent->firstChild();
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
{
- // Fill tqchildren list with direct tqchildren
+ // Fill children list with direct children
KFileInfo *child = _parent->firstChild();
while ( child )
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
}
- // Append the dot entry's tqchildren to the tqchildren list
+ // Append the dot entry's children to the children list
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
- // Create a temporary list for the dot entry tqchildren
+ // Create a temporary list for the dot entry children
KFileInfoList dotEntryChildrenList( _sortOrder, _ascending );
child = _parent->dotEntry()->firstChild();
@@ -255,13 +255,13 @@ void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
dotEntryChildrenList.sort();
- // Now append all of this dot entry tqchildren list to the tqchildren list
+ // Now append all of this dot entry children list to the children list
child = dotEntryChildrenList.first();
while ( child )